`define NUM_CORE 10

module oc_m1_core_top(handsome_clk, handsome_din_top, handsome_dout_top, sys_clock_i, sys_reset_i);
	input handsome_clk;
	input handsome_din_top;
	output handsome_dout_top;
	input sys_clock_i;
	input sys_reset_i;

localparam input_width = 34;
localparam output_width = 71;
localparam reducer_log4 = 4;
localparam reducer_log4_top = 2;

wire [`NUM_CORE-1:0] sys_irq_i;
wire [`NUM_CORE-1:0] wb_ack_i;
wire [`NUM_CORE-1:0] wb_cyc_o;
wire [`NUM_CORE-1:0] wb_stb_o;
wire [`NUM_CORE-1:0] wb_we_o;
wire [31:0] wb_dat_i [`NUM_CORE-1:0];
wire [31:0] wb_adr_o [`NUM_CORE-1:0];
wire [31:0] wb_dat_o [`NUM_CORE-1:0];
wire [3:0] wb_sel_o [`NUM_CORE-1:0];
wire [`NUM_CORE-1:0] handsome_din;
wire [`NUM_CORE-1:0] handsome_dout;

handsome_lfsr #(`NUM_CORE) input_lfsr_top (
			.clock(handsome_clk),
			.input_bit(handsome_din_top),
			.output_vector(handsome_din));

generate
begin:G1
	genvar i;
	for (i = 0; i < `NUM_CORE; i = i+1)
	begin :stamp_inst

		handsome_lfsr #(input_width) input_lfsr (
			.clock(handsome_clk),
			.input_bit(handsome_din[i]),
			.output_vector({sys_irq_i[i],wb_ack_i[i],wb_dat_i[i]}));

		oc_m1_core oc_stamp(
			.sys_clock_i(sys_clock_i),
			.sys_reset_i(sys_reset_i),
			.sys_irq_i(sys_irq_i[i]),
			.wb_ack_i(wb_ack_i[i]),
			.wb_dat_i(wb_dat_i[i]),
			.wb_cyc_o(wb_cyc_o[i]),
			.wb_stb_o(wb_stb_o[i]),
			.wb_we_o(wb_we_o[i]),
			.wb_adr_o(wb_adr_o[i]),
			.wb_dat_o(wb_dat_o[i]),
			.wb_sel_o(wb_sel_o[i]));

		handsome_reducer #(reducer_log4) output_reducer (
			.clock(handsome_clk),
			.input_vector({wb_cyc_o[i],wb_stb_o[i],wb_we_o[i],wb_adr_o[i],wb_dat_o[i],wb_sel_o[i]}),
			.output_bit(handsome_dout[i]));

	end

handsome_reducer #(reducer_log4_top) output_reducer_top (
	.clock(handsome_clk),
	.input_vector(handsome_dout[`NUM_CORE-1:0]),
	.output_bit(handsome_dout_top));

end
endgenerate
endmodule
